Examples
========

.. toctree::
   :maxdepth: 1

   BinaryExamples
   TernaryExamples
   UsingCalculationResults
   ChargedPhases
   ReferenceStateExamples
   PlotActivity
   EquilibriumWithOrdering
   ViscosityModel
   CementiteAnalysis
